@@ -1,20 +1,22 @@
-/* Copyright (C) 1999-2001 Free Software Foundation, Inc.
-   This file is part of the GNU ICONV Library.
-
-   The GNU ICONV Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
-
-   The GNU ICONV Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU ICONV Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+/*
+ * Copyright (C) 1999-2002 Free Software Foundation, Inc.
+ * This file is part of the GNU LIBICONV Library.
+ *
+ * The GNU LIBICONV Library is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * The GNU LIBICONV Library is distributed in the hope that it will be
+ * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
+ * If not, write to the Free Software Foundation, Inc., 59 Temple Place -
+ * Suite 330, Boston, MA 02111-1307, USA.
+ */
 
 /* This file defines all the converters. */
 
@@ -38,11 +40,22 @@ struct mbtowc_funcs {
    * converts the byte sequence starting at s to a wide character. Up to n bytes
    * are available at s. n is >= 1.
    * Result is number of bytes consumed (if a wide character was read),
-   * or 0 if invalid, or -1 if n too small, or -1-(number of bytes consumed)
+   * or -1 if invalid, or -2 if n too small, or -2-(number of bytes consumed)
    * if only a shift sequence was read.
    */
+  int (*xxx_flushwc) (conv_t conv, ucs4_t *pwc);
+  /*
+   * int xxx_flushwc (conv_t conv, ucs4_t *pwc)
+   * returns to the initial state and stores the pending wide character, if any.
+   * Result is 1 (if a wide character was read) or 0 if none was pending.
+   */
 };
 
+/* Return code if invalid. (xxx_mbtowc) */
+#define RET_ILSEQ      -1
+/* Return code if only a shift sequence of n bytes was read. (xxx_mbtowc) */
+#define RET_TOOFEW(n)  (-2-(n))
+
 /*
  * Data type for conversion unicode -> multibyte
  */
@@ -52,23 +65,21 @@ struct wctomb_funcs {
    * int xxx_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
    * converts the wide character wc to the character set xxx, and stores the
    * result beginning at r. Up to n bytes may be written at r. n is >= 1.
-   * Result is number of bytes written, or 0 if invalid, or -1 if n too small.
+   * Result is number of bytes written, or -1 if invalid, or -2 if n too small.
    */
   int (*xxx_reset) (conv_t conv, unsigned char *r, int n);
   /*
    * int xxx_reset (conv_t conv, unsigned char *r, int n)
    * stores a shift sequences returning to the initial state beginning at r.
    * Up to n bytes may be written at r. n is >= 0.
-   * Result is number of bytes written, or -1 if n too small.
+   * Result is number of bytes written, or -2 if n too small.
    */
 };
 
-/* Return code if invalid. (xxx_mbtowc, xxx_wctomb) */
-#define RET_ILSEQ      0
-/* Return code if only a shift sequence of n bytes was read. (xxx_mbtowc) */
-#define RET_TOOFEW(n)  (-1-(n))
+/* Return code if invalid. (xxx_wctomb) */
+#define RET_ILUNI      -1
 /* Return code if output buffer is too small. (xxx_wctomb, xxx_reset) */
-#define RET_TOOSMALL   -1
+#define RET_TOOSMALL   -2
 
 /*
  * Contents of a conversion descriptor.
@@ -86,6 +97,7 @@ struct conv_struct {
   state_t ostate;
   /* Operation flags */
   int transliterate;
+  int discard_ilseq;
 };
 
 /*
@@ -105,11 +117,15 @@ struct conv_struct {
 #include "utf16.h"
 #include "utf16be.h"
 #include "utf16le.h"
+#include "utf32.h"
+#include "utf32be.h"
+#include "utf32le.h"
 #include "utf7.h"
 #include "ucs2internal.h"
 #include "ucs2swapped.h"
 #include "ucs4internal.h"
 #include "ucs4swapped.h"
+#include "c99.h"
 #include "java.h"
 
 /* 8-bit encodings */
@@ -159,6 +175,7 @@ struct conv_struct {
 #include "armscii_8.h"
 #include "georgian_academy.h"
 #include "georgian_ps.h"
+#include "koi8_t.h"
 #include "mulelao.h"
 #include "cp1133.h"
 #include "tis620.h"
@@ -223,6 +240,9 @@ typedef struct {
 #include "cp1046.h"
 #include "cp1124.h"
 #include "cp1129.h"
+#include "cp1161.h"
+#include "cp1162.h"
+#include "cp1163.h"
 #endif
 
 #ifdef USE_OSF1
@@ -232,13 +252,27 @@ typedef struct {
 
 #ifdef USE_DOS
 #include "cp437.h"
+#include "cp737.h"
 #include "cp775.h"
 #include "cp852.h"
+#include "cp853.h"
 #include "cp855.h"
 #include "cp857.h"
+#include "cp858.h"
+#include "cp860.h"
 #include "cp861.h"
+#include "cp863.h"
 #include "cp864.h"
 #include "cp865.h"
 #include "cp869.h"
+#include "cp1125.h"
+#endif
+
+#ifdef USE_EXTRA
+#include "euc_jisx0213.h"
+#include "shift_jisx0213.h"
+#include "iso2022_jp3.h"
+#include "tds565.h"
+#include "riscos1.h"
 #endif
 
