@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Free Software Foundation, Inc.
+/* Copyright (C) 2000-2003 Free Software Foundation, Inc.
    This file is part of the GNU LIBICONV Library.
 
    The GNU LIBICONV Library is free software; you can redistribute it
@@ -17,6 +17,10 @@
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "config.h"
+#ifndef ICONV_CONST
+# define ICONV_CONST const
+#endif
+
 #include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -28,42 +32,19 @@
 #endif
 #include <fcntl.h>
 
+/* Ensure that iconv_no_i18n does not depend on libintl.  */
 #ifdef NO_I18N
 # undef ENABLE_NLS
+# undef ENABLE_RELOCATABLE
 #endif
+
+#include "binary-io.h"
+#include "progname.h"
+#include "relocatable.h"
 #include "gettext.h"
 
 #define _(str) gettext(str)
 
-/* For systems that distinguish between text and binary I/O.
-   O_BINARY is usually declared in <fcntl.h>. */
-#if !defined O_BINARY && defined _O_BINARY
-  /* For MSC-compatible compilers.  */
-# define O_BINARY _O_BINARY
-# define O_TEXT _O_TEXT
-#endif
-#ifdef __BEOS__
-  /* BeOS 5 has O_BINARY and O_TEXT, but they have no effect.  */
-# undef O_BINARY
-# undef O_TEXT
-#endif
-#if O_BINARY
-# if !(defined(__EMX__) || defined(__DJGPP__))
-#  define setmode _setmode
-#  define fileno _fileno
-# endif
-# ifdef __DJGPP__
-#  include <io.h> /* declares setmode() */
-#  include <unistd.h> /* declares isatty() */
-#  /* Avoid putting stdin/stdout in binary mode if it is connected to the
-#     console, because that would make it impossible for the user to
-#     interrupt the program through Ctrl-C or Ctrl-Break.  */
-#  define SET_BINARY(fd) (!isatty(fd) ? (setmode(fd,O_BINARY), 0) : 0)
-# else
-#  define SET_BINARY(fd) setmode(fd,O_BINARY)
-# endif
-#endif
-
 #if O_BINARY
   static int force_binary = 0;
 #endif
@@ -241,6 +222,7 @@ int main (int argc, char* argv[])
   int i;
   int status;
 
+  set_program_name (argv[0]);
 #if HAVE_SETLOCALE
   /* Needed for the locale dependent encodings, "char" and "wchar_t",
      and for gettext. */
@@ -250,7 +232,9 @@ int main (int argc, char* argv[])
   setlocale(LC_MESSAGES,"");
 #endif
 #endif
-  bindtextdomain("libiconv",LOCALEDIR);
+#if ENABLE_NLS
+  bindtextdomain("libiconv",relocate(LOCALEDIR));
+#endif
   textdomain("libiconv");
   for (i = 1; i < argc;) {
     if (!strcmp(argv[i],"-f")) {
@@ -345,7 +329,7 @@ int main (int argc, char* argv[])
     }
     iconv_close(cd);
   }
-  if (ferror(stdout)) {
+  if (fflush(stdout) || ferror(stdout)) {
     fprintf(stderr,_("iconv: I/O error\n"));
     status = 1;
   }
